[−][src]Enum c2rust_refactor::interact::ToServer
Variants
AddMarkAdd a mark with label label to a node of the indicated kind at file, line, col.
Fields of AddMark
RemoveMarkRemove all marks from node id.
Fields of RemoveMark
id: usizeGetMarkInfoGet details about the marks on node id.
Fields of GetMarkInfo
id: usizeGetMarkListGet a list of all marks.
SetBuffersAvailableProvide the server with a list of available buffers. If the compiler would load one of the named files, the server will request its contents from the client, instead of reading the contents on disk.
Fields of SetBuffersAvailable
BufferTextProvide the server with the contents of a buffer.
Fields of BufferText
RunCommandRun a refactoring command.
Fields of RunCommand