[−][src]Struct c2rust_refactor::matcher::BindingTypes
A set of binding types, mapping names to binding types.
Methods
impl BindingTypes[src]
pub fn new() -> BindingTypes[src]
pub fn get(&self, name: &Symbol) -> Option<&Type>[src]
pub fn set_type<S: IntoSymbol>(&mut self, name: S, ty: Type)[src]
Set the type for a name, so that the name matches (and captures) only nodes of the appropriate typ.
pub fn merge(&mut self, other: Self)[src]