[−][src]Module c2rust_refactor::select
A simple scripting language for marking a set of nodes.
This module provides a command select <label> <script>. The script is a sequence of commands,
which manipulate a set of nodes called the "current selection". When the script completes, the
select command marks all nodes in the current selection with the given label. See the docs
for SelectOp for descriptions of the available commands.
Re-exports
pub use self::filter::ItemLikeKind; |
Modules
| filter | |
| parse | |
| visitor | Visitors for implementing |
Enums
| AnyPattern | |
| Filter | Filters used in certain script commands. |
| SelectOp | Commands of the select scripting language. In the concrete syntax, each command ends with a semicolon. |
Functions
| register_commands | |
| run_select | Implementation of the |