[−][src]Enum c2rust_refactor::select::SelectOp
Commands of the select scripting language. In the concrete syntax, each command ends with a semicolon.
Variants
Marked(Symbol)marked(l): Select all nodes that are already marked with label l.
Mark(Symbol)mark(l): Add a mark with label l to all selected nodes.
Unmark(Symbol)unmark(l): Remove any marks with label l from all selected nodes.
Resetreset: Clear the current selection.
Cratecrate: Select the crate root.
Item(Path)item(p): Select the item with the path p.
ChildMatch(Filter)child(f): Replace the current selection with the set of all nodes that are direct
children of selected nodes and that match filter f.
DescMatch(Filter)desc(f): Replace the current selection with the set of all nodes that are descendants of
selected nodes and that match filter f.
Filter(Filter)filter(f): Filter the set of selected nodes, keeping only nodes that match filter f.
Firstfirst: Select the first (lowest NodeId) of the selected nodes.
Lastlast: Select the last (highest NodeId) of the selected nodes.