[−][src]Module c2rust_refactor::transform
AST transformation implementations. Most c2rust-refactor commands are transforms implemented in the
submodules of this module.
Modules
| canonicalize_refs | |
| char_literals | |
| control_flow | |
| externs | |
| format | |
| funcs | |
| generics | |
| ionize | |
| items | |
| linkage | |
| literals | |
| ownership | |
| reorganize_definitions | |
| retype | |
| rewrite | |
| statics | |
| structs | |
| test | Transformation passes used for testing parts of the system. |
| vars | |
| wrapping_arith |
Structs
| TransformCommand | Adapter for turning a |
Traits
| Transform | An AST transformation that can be applied to a crate. |
Functions
| register_commands |