[−][src]Module c2rust_refactor::transform::test
Transformation passes used for testing parts of the system.
Structs
| FPlusOne |
|
| InsertRemoveArgs |
|
| OnePlusOne |
|
| ReplaceStmts |
|
| TestDebugCallees |
|
| TestTypeckLoop |
|
Functions
| register_commands |
Transformation passes used for testing parts of the system.
| FPlusOne |
|
| InsertRemoveArgs |
|
| OnePlusOne |
|
| ReplaceStmts |
|
| TestDebugCallees |
|
| TestTypeckLoop |
|
| register_commands |