[−][src]Module c2rust_refactor::util::dataflow
Worklist algorithm for finding fixed points.
Structs
| Ctxt | Worklist algorithm context. |
Functions
| iterate | Run an iterative worklist algorithm to find a fixed point. |
Worklist algorithm for finding fixed points.
| Ctxt | Worklist algorithm context. |
| iterate | Run an iterative worklist algorithm to find a fixed point. |