[][src]Struct c2rust_refactor::util::dataflow::Ctxt

pub struct Ctxt<'a, K: 'a, V: 'a> { /* fields omitted */ }

Worklist algorithm context. K is the type of keys, which identify nodes, and V is the type of value associated with each node. Allows indexing to retrieve data from other nodes. Accessing the current node's data triggers a panic.