[−][src]Struct c2rust_refactor::transform::rewrite::RewriteStmts
rewrite_stmts Command
Usage: rewrite_stmts PAT REPL
For every statement sequence in the crate matching PAT, replace it with REPL. PAT and
REPL are both Rust statement sequences. PAT can use placeholders to capture nodes from
the matched AST, and REPL can refer to those same placeholders to substitute
in the captured nodes. See the matcher module for details on AST pattern
matching.
See the documentation for rewrite_expr for an example of this style of
rewriting.
Fields
pat: Stringrepl: StringTrait Implementations
impl Transform for RewriteStmts[src]
fn transform(&self, krate: &mut Crate, st: &CommandState, cx: &RefactorCtxt)[src]
fn min_phase(&self) -> Phase[src]